package gregapi.old.interfaces.internal;

import static gregapi.data.CS.F;
import net.minecraft.item.ItemStack;
import net.minecraftforge.fluids.Fluid;
import net.minecraftforge.fluids.FluidStack;

public interface IGT_RecipeAdder {
	/**
	 * Adds a FusionreactorRecipe
	 * @param aInput1 = first Input (not null, and respects StackSize)
	 * @param aInput2 = second Input (not null, and respects StackSize)
	 * @param aOutput = Output of the Fusion (can be null, and respects StackSize)
	 * @param aFusionDurationInTicks = How many ticks the Fusion lasts (must be > 0)
	 * @param aFusionEnergyPerTick = The EU generated per Tick (can even be negative!)
	 * @param aEnergyNeededForStartingFusion = EU needed for heating the Reactor up (must be >= 0)
	 * @return true if the Recipe got added, otherwise false.
	 */
	public boolean addFusionReactorRecipe(ItemStack aInput1, ItemStack aInput2, ItemStack aOutput1, long aFusionDurationInTicks, long aFusionEnergyPerTick, long aEnergyNeededForStartingFusion);
	
	/**
	 * Adds a Centrifuge Recipe
	 * @param aInput1 must be != null
	 * @param aCellInput this is for the needed Cells, > 0 for Tincellcount, < 0 for negative Fuelcancount, == 0 for nothing
	 * @param aOutput1 must be != null
	 * @param aOutput2 can be null
	 * @param aOutput3 can be null
	 * @param aOutput4 can be null
	 * @param aDuration must be > 0
	 */
	public boolean addCentrifugeRecipe(ItemStack aInput1, long aInput2, ItemStack aOutput1, ItemStack aOutput2, ItemStack aOutput3, ItemStack aOutput4, ItemStack aOutput5, ItemStack aOutput6, long aDuration);
	
	/**
	 * Adds a Centrifuge Recipe
	 * @param aInput1 must be != null
	 * @param aOutput1 must be != null
	 * @param aOutput2 can be null
	 * @param aOutput3 can be null
	 * @param aOutput4 can be null
	 * @param aDuration must be > 0
	 */
	public boolean addCentrifugeRecipe(ItemStack aInput1, ItemStack aInput2, FluidStack aFluidInput, FluidStack aFluidOutput, ItemStack aOutput1, ItemStack aOutput2, ItemStack aOutput3, ItemStack aOutput4, ItemStack aOutput5, ItemStack aOutput6, long[] aChances, long aDuration, long aEUt);
	
	/**
	 * Adds a Electrolyzer Recipe
	 * @param aInput1 must be != null
	 * @param aCellInput this is for the needed Cells, > 0 for Tincellcount, < 0 for negative Fuelcancount, == 0 for nothing
	 * @param aOutput1 must be != null
	 * @param aOutput2 can be null
	 * @param aOutput3 can be null
	 * @param aOutput4 can be null
	 * @param aDuration must be > 0
	 * @param aEUt should be > 0
	 */
	public boolean addElectrolyzerRecipe(ItemStack aInput1, long aInput2, ItemStack aOutput1, ItemStack aOutput2, ItemStack aOutput3, ItemStack aOutput4, ItemStack aOutput5, ItemStack aOutput6, long aDuration, long aEUt);
	
	/**
	 * Adds a Electrolyzer Recipe
	 * @param aInput1 must be != null
	 * @param aCellInput this is for the needed Cells, > 0 for Tincellcount, < 0 for negative Fuelcancount, == 0 for nothing
	 * @param aOutput1 must be != null
	 * @param aOutput2 can be null
	 * @param aOutput3 can be null
	 * @param aOutput4 can be null
	 * @param aDuration must be > 0
	 * @param aEUt should be > 0
	 */
	public boolean addElectrolyzerRecipe(ItemStack aInput1, ItemStack aInput2, FluidStack aFluidInput, FluidStack aFluidOutput, ItemStack aOutput1, ItemStack aOutput2, ItemStack aOutput3, ItemStack aOutput4, ItemStack aOutput5, ItemStack aOutput6, long[] aChances, long aDuration, long aEUt);
	
	/**
	 * Adds a Chemical Recipe
	 * @param aInput1 must be != null
	 * @param aInput2 must be != null
	 * @param aOutput1 must be != null
	 * @param aDuration must be > 0
	 */
	public boolean addChemicalRecipe(ItemStack aInput1, ItemStack aInput2, ItemStack aOutput, long aDuration);
	
	/**
	 * Adds a Chemical Recipe
	 * @param aInput1 must be != null
	 * @param aInput2 must be != null
	 * @param aOutput1 must be != null
	 * @param aDuration must be > 0
	 */
	public boolean addChemicalRecipe(ItemStack aInput1, ItemStack aInput2, FluidStack aFluidInput, FluidStack aFluidOutput, ItemStack aOutput, long aDuration);
	
	/**
	 * Adds a Blast Furnace Recipe
	 * @param aInput1 must be != null
	 * @param aInput2 can be null
	 * @param aOutput1 must be != null
	 * @param aOutput2 can be null
	 * @param aDuration must be > 0
	 * @param aEUt should be > 0
	 * @param aLevel should be > 0 is the minimum Heat Level needed for this Recipe
	 */
	@Deprecated
	public boolean addBlastRecipe(ItemStack aInput1, ItemStack aInput2, ItemStack aOutput1, ItemStack aOutput2, long aDuration, long aEUt, long aLevel);
	
	/**
	 * Adds a Blast Furnace Recipe
	 * @param aInput1 must be != null
	 * @param aInput2 can be null
	 * @param aOutput1 must be != null
	 * @param aOutput2 can be null
	 * @param aDuration must be > 0
	 * @param aEUt should be > 0
	 * @param aLevel should be > 0 is the minimum Heat Level needed for this Recipe
	 */
	public boolean addBlastRecipe(ItemStack aInput1, ItemStack aInput2, FluidStack aFluidInput, FluidStack aFluidOutput, ItemStack aOutput1, ItemStack aOutput2, long aDuration, long aEUt, long aLevel);
	
	/**
	 * Adds a Canning Machine Recipe
	 * @param aInput1 must be != null
	 * @param aOutput1 must be != null
	 * @param aDuration must be > 0, 100 ticks is standard.
	 * @param aEUt should be > 0, 1 EU/t is standard.
	 */
	public boolean addCannerRecipe(ItemStack aInput1, ItemStack aInput2, ItemStack aOutput1, ItemStack aOutput2, long aDuration, long aEUt);
	
	/**
	 * Adds an Alloy Smelter Recipe
	 * @param aInput1 must be != null
	 * @param aInput2 can be null
	 * @param aOutput1 must be != null
	 * @param aOutput2 can be null
	 * @param aDuration must be > 0
	 * @param aEUt should be > 0
	 */
	public boolean addAlloySmelterRecipe(ItemStack aInput1, ItemStack aInput2, ItemStack aOutput1, long aDuration, long aEUt);
	
	/**
	 * Adds a CNC-Machine Recipe
	 * @param aInput1 must be != null
	 * @param aOutput1 must be != null
	 * @param aDuration must be > 0
	 * @param aEUt should be > 0
	 */
	public boolean addCNCRecipe(ItemStack aInput1, ItemStack aOutput1, long aDuration, long aEUt);
	
	/**
	 * Adds a Circuit Assembler Recipe
	 * @param aInput1 must be != null
	 * @param aOutput1 must be != null
	 * @param aDuration must be > 0
	 * @param aEUt should be > 0
	 */
	public boolean addAssemblerRecipe(ItemStack aInput1, ItemStack aInput2, ItemStack aOutput1, long aDuration, long aEUt);
	
	/**
	 * Adds a Circuit Assembler Recipe
	 * @param aInput1 must be != null
	 * @param aOutput1 must be != null
	 * @param aDuration must be > 0
	 * @param aEUt should be > 0
	 */
	public boolean addAssemblerRecipe(ItemStack aInput1, ItemStack aInput2, FluidStack aFluidInput, ItemStack aOutput1, long aDuration, long aEUt);
	
	/**
	 * Adds a Forge Hammer Recipe
	 * @param aInput1 must be != null
	 * @param aOutput1 must be != null
	 * @param aDuration must be > 0
	 * @param aEUt should be > 0
	 */
	public boolean addForgeHammerRecipe(ItemStack aInput1, ItemStack aOutput1, long aDuration, long aEUt);

	/**
	 * Adds a Wiremill Recipe
	 * @param aInput1 must be != null
	 * @param aOutput1 must be != null
	 * @param aDuration must be > 0
	 * @param aEUt should be > 0
	 */
	public boolean addWiremillRecipe(ItemStack aInput, ItemStack aOutput, long aDuration, long aEUt);
	
	/**
	 * Adds a Polariser Recipe
	 * @param aInput1 must be != null
	 * @param aOutput1 must be != null
	 * @param aDuration must be > 0
	 * @param aEUt should be > 0
	 */
	public boolean addPolarizerRecipe(ItemStack aInput, ItemStack aOutput, long aDuration, long aEUt);
	
	/**
	 * Adds a Plate Bending Machine Recipe
	 * @param aInput1 must be != null
	 * @param aOutput1 must be != null
	 * @param aDuration must be > 0
	 * @param aEUt should be > 0
	 */
	public boolean addBenderRecipe(ItemStack aInput, ItemStack aOutput, long aDuration, long aEUt);
	
	/**
	 * Adds a Extruder Machine Recipe
	 * @param aInput1 must be != null
	 * @param aShape must be != null, Set the stackSize to 0 if you don't want to let it consume this Item.
	 * @param aOutput1 must be != null
	 * @param aDuration must be > 0
	 * @param aEUt should be > 0
	 */
	public boolean addExtruderRecipe(ItemStack aInput, ItemStack aShape, ItemStack aOutput, long aDuration, long aEUt);
	
	/**
	 * Adds a Slicer Machine Recipe
	 * @param aInput1 must be != null
	 * @param aShape must be != null, Set the stackSize to 0 if you don't want to let it consume this Item.
	 * @param aOutput1 must be != null
	 * @param aDuration must be > 0
	 * @param aEUt should be > 0
	 */
	public boolean addSlicerRecipe(ItemStack aInput, ItemStack aShape, ItemStack aOutput, long aDuration, long aEUt);
	
	/**
	 * Adds an Implosion Compressor Recipe
	 * @param aInput1 must be != null
	 * @param aInput2 amount of ITNT, should be > 0
	 * @param aOutput1 must be != null
	 * @param aOutput2 can be null
	 */
	public boolean addImplosionRecipe(ItemStack aInput1, long aInput2, ItemStack aOutput1, ItemStack aOutput2);
	
	/**
	 * Adds a Grinder Recipe
	 * @param aInput1 must be != null
	 * @param aInput2 id for the Cell needed for this Recipe
	 * @param aOutput1 must be != null
	 * @param aOutput2 can be null
	 * @param aOutput3 can be null
	 * @param aOutput4 can be null
	 */
	public boolean addGrinderRecipe(ItemStack aInput1, ItemStack aInput2, ItemStack aOutput1, ItemStack aOutput2, ItemStack aOutput3, ItemStack aOutput4);
	
	/**
	 * Adds a Distillation Tower Recipe
	 */
	public boolean addDistillationRecipe(ItemStack aInput1, long aInput2, ItemStack aOutput1, ItemStack aOutput2, ItemStack aOutput3, ItemStack aOutput4, long aDuration, long aEUt);
	
	/**
	 * Adds a Lathe Machine Recipe
	 */
	public boolean addLatheRecipe(ItemStack aInput1, ItemStack aOutput1, ItemStack aOutput2, long aDuration, long aEUt);
	
	/**
	 * Adds a Cutter Recipe
	 */
	public boolean addCutterRecipe(ItemStack aInput, FluidStack aLubricant, ItemStack aOutput1, ItemStack aOutput2, long aDuration, long aEUt);
	
	/**
	 * Adds Cutter Recipes with default Lubricants
	 */
	public boolean addCutterRecipe(ItemStack aInput, ItemStack aOutput1, ItemStack aOutput2, long aDuration, long aEUt);
	
	/**
	 * Adds a Boxing Recipe
	 */
	public boolean addBoxingRecipe(ItemStack aContainedItem, ItemStack aEmptyBox, ItemStack aFullBox, long aDuration, long aEUt);
	
	/**
	 * Adds an Unboxing Recipe
	 */
	public boolean addUnboxingRecipe(ItemStack aFullBox, ItemStack aContainedItem, ItemStack aEmptyBox, long aDuration, long aEUt);
	
	/**
	 * Adds a Vacuum Freezer Recipe
	 * @param aInput1 must be != null
	 * @param aOutput1 must be != null
	 * @param aDuration must be > 0
	 */
	public boolean addVacuumFreezerRecipe(ItemStack aInput1, ItemStack aOutput1, long aDuration);
	
	/**
	 * Adds a Fuel for My Generators
	 * @param aInput1 must be != null
	 * @param aOutput1 can be null
	 * @param aEU EU per MilliBucket. If no Liquid Form of this Container is available, then it will give you EU*1000 per Item.
	 * @param aType 0 = Diesel; 1 = Gas Turbine; 2 = Thermal; 3 = Dense Fluid; 4 = Plasma; 5 = Magic; And if something is unclear or missing, then look at the GT_Recipe-Class
	 */
	public boolean addFuel(ItemStack aInput1, ItemStack aOutput1, long aEU, long aType);
	
	/**
	 * Adds an Amplifier Recipe for the Amplifabricator
	 */
	public boolean addAmplifier(ItemStack aAmplifierItem, long aDuration, long aAmplifierAmountOutputted);
	
	/**
	 * Adds a Recipe for the Brewing Machine (intentionally limited to Fluid IDs)
	 */
	public boolean addBrewingRecipe(ItemStack aIngredient, Fluid aInput, Fluid aOutput, boolean aHidden);
	
	/**
	 * Adds a Recipe for the Fermenter
	 */
	public boolean addFermentingRecipe(FluidStack aInput, FluidStack aOutput, long aDuration, boolean aHidden);
	
	/**
	 * Adds a Recipe for the Fluid Heater
	 */
	public boolean addFluidHeaterRecipe(ItemStack aCircuit, FluidStack aInput, FluidStack aOutput, long aDuration, long aEUt);
	
	/**
	 * Adds a Recipe for the Distillery
	 */
	public boolean addDistilleryRecipe(ItemStack aCircuit, FluidStack aInput, FluidStack aOutput, long aDuration, long aEUt, boolean aHidden);
	
	/**
	 * Adds a Recipe for the Fluid Solidifier
	 */
	public boolean addFluidSolidifierRecipe(ItemStack aMold, FluidStack aInput, ItemStack aOutput, long aDuration, long aEUt);
	
	/**
	 * Adds a Recipe for Fluid Smelting
	 */
	public boolean addFluidSmelterRecipe(ItemStack aInput, ItemStack aRemains, FluidStack aOutput, long aChance, long aDuration, long aEUt);
	
	/**
	 * Adds a Recipe for Fluid Extraction
	 */
	public boolean addFluidExtractionRecipe(ItemStack aInput, ItemStack aRemains, FluidStack aOutput, long aChance, long aDuration, long aEUt);
	
	/**
	 * Adds a Recipe for the Fluid Canner
	 */
	public boolean addFluidCannerRecipe(ItemStack aInput, ItemStack aOutput, FluidStack aFluidInput, FluidStack aFluidOutput);

	/**
	 * Adds a Recipe for the Chemical Bath
	 */
	public boolean addChemicalBathRecipe(ItemStack aInput, FluidStack aBathingFluid, ItemStack aOutput1, ItemStack aOutput2, ItemStack aOutput3, long[] aChances, long aDuration, long aEUt);
	
	/**
	 * Adds a Recipe for the Electromagnetic Separator
	 */
	public boolean addElectromagneticSeparatorRecipe(ItemStack aInput, ItemStack aOutput1, ItemStack aOutput2, ItemStack aOutput3, long[] aChances, long aDuration, long aEUt);
	
	/**
	 * Adds a Recipe for the Printer
	 */
	public boolean addPrinterRecipe(ItemStack aInput, FluidStack aFluid, ItemStack aSpecialSlot, ItemStack aOutput, long aDuration, long aEUt);
	
	/**
	 * Adds a Recipe for the Autoclave
	 */
	public boolean addAutoclaveRecipe(ItemStack aInput, FluidStack aFluid, ItemStack aOutput, long aChance, long aDuration, long aEUt);
	
	/**
	 * Adds a Recipe for the Mixer
	 */
	public boolean addMixerRecipe(ItemStack aInput1, ItemStack aInput2, ItemStack aInput3, ItemStack aInput4, FluidStack aFluidInput, FluidStack aFluidOutput, ItemStack aOutput, long aDuration, long aEUt);
	
	/**
	 * Adds a Recipe for the Laser Engraver
	 */
	public boolean addLaserEngraverRecipe(ItemStack aItemToEngrave, ItemStack aLens, ItemStack aEngravedItem, long aDuration, long aEUt);
	
	/**
	 * Adds a Recipe for the Forming Press
	 */
	public boolean addFormingPressRecipe(ItemStack aItemToImprint, ItemStack aForm, ItemStack aImprintedItem, long aDuration, long aEUt);
	
	/**
	 * Adds a Recipe for the Sifter. (up to 12 Outputs)
	 */
	public boolean addSifterRecipe(ItemStack aItemToSift, ItemStack[] aSiftedItems, long[] aChances, long aDuration, long aEUt);
	
	/**
	 * Adds a Recipe for the Arc Furnace. (up to 4 Outputs)
	 */
	public boolean addArcFurnaceRecipe(ItemStack aInput, ItemStack[] aOutputs, long[] aChances, long aDuration, long aEUt);
	
	public boolean addPulveriserRecipe(ItemStack aInput, ItemStack[] aOutputs, long[] aChances, long aDuration, long aEUt);
	public boolean addShredderRecipe(ItemStack aInput, ItemStack[] aOutputs, long[] aChances, long aDuration, long aEUt);
	public boolean addCrusherRecipe(ItemStack aInput, ItemStack[] aOutputs, long[] aChances, long aDuration, long aEUt);
	public boolean addSharpeningRecipe(ItemStack aItemToSharpen, ItemStack aSharpenedItem, ItemStack aRemainingDust, long aDustChance, long aDuration, long aEUt);
	
	public static class NonWorkingRecipeAdder implements IGT_RecipeAdder {
		@Override public boolean addFusionReactorRecipe(ItemStack aInput1, ItemStack aInput2, ItemStack aOutput1, long aFusionDurationInTicks, long aFusionEnergyPerTick, long aEnergyNeededForStartingFusion) {return F;}
		@Override public boolean addCentrifugeRecipe(ItemStack aInput1, long aInput2, ItemStack aOutput1, ItemStack aOutput2, ItemStack aOutput3, ItemStack aOutput4, ItemStack aOutput5, ItemStack aOutput6, long aDuration) {return F;}
		@Override public boolean addCentrifugeRecipe(ItemStack aInput1, ItemStack aInput2, FluidStack aFluidInput, FluidStack aFluidOutput, ItemStack aOutput1, ItemStack aOutput2, ItemStack aOutput3, ItemStack aOutput4, ItemStack aOutput5, ItemStack aOutput6, long[] aChances, long aDuration, long aEUt) {return F;}
		@Override public boolean addElectrolyzerRecipe(ItemStack aInput1, long aInput2, ItemStack aOutput1, ItemStack aOutput2, ItemStack aOutput3, ItemStack aOutput4, ItemStack aOutput5, ItemStack aOutput6, long aDuration, long aEUt) {return F;}
		@Override public boolean addElectrolyzerRecipe(ItemStack aInput1, ItemStack aInput2, FluidStack aFluidInput, FluidStack aFluidOutput, ItemStack aOutput1, ItemStack aOutput2, ItemStack aOutput3, ItemStack aOutput4, ItemStack aOutput5, ItemStack aOutput6, long[] aChances, long aDuration, long aEUt) {return F;}
		@Override public boolean addChemicalRecipe(ItemStack aInput1, ItemStack aInput2, ItemStack aOutput, long aDuration) {return F;}
		@Override public boolean addChemicalRecipe(ItemStack aInput1, ItemStack aInput2, FluidStack aFluidInput, FluidStack aFluidOutput, ItemStack aOutput, long aDuration) {return F;}
		@Override public boolean addBlastRecipe(ItemStack aInput1, ItemStack aInput2, ItemStack aOutput1, ItemStack aOutput2, long aDuration, long aEUt, long aLevel) {return F;}
		@Override public boolean addBlastRecipe(ItemStack aInput1, ItemStack aInput2, FluidStack aFluidInput, FluidStack aFluidOutput, ItemStack aOutput1, ItemStack aOutput2, long aDuration, long aEUt, long aLevel) {return F;}
		@Override public boolean addCannerRecipe(ItemStack aInput1, ItemStack aInput2, ItemStack aOutput1, ItemStack aOutput2, long aDuration, long aEUt) {return F;}
		@Override public boolean addAlloySmelterRecipe(ItemStack aInput1, ItemStack aInput2, ItemStack aOutput1, long aDuration, long aEUt) {return F;}
		@Override public boolean addCNCRecipe(ItemStack aInput1, ItemStack aOutput1, long aDuration, long aEUt) {return F;}
		@Override public boolean addAssemblerRecipe(ItemStack aInput1, ItemStack aInput2, ItemStack aOutput1, long aDuration, long aEUt) {return F;}
		@Override public boolean addAssemblerRecipe(ItemStack aInput1, ItemStack aInput2, FluidStack aFluidInput, ItemStack aOutput1, long aDuration, long aEUt) {return F;}
		@Override public boolean addForgeHammerRecipe(ItemStack aInput1, ItemStack aOutput1, long aDuration, long aEUt) {return F;}
		@Override public boolean addWiremillRecipe(ItemStack aInput, ItemStack aOutput, long aDuration, long aEUt) {return F;}
		@Override public boolean addPolarizerRecipe(ItemStack aInput, ItemStack aOutput, long aDuration, long aEUt) {return F;}
		@Override public boolean addBenderRecipe(ItemStack aInput, ItemStack aOutput, long aDuration, long aEUt) {return F;}
		@Override public boolean addExtruderRecipe(ItemStack aInput, ItemStack aShape, ItemStack aOutput, long aDuration, long aEUt) {return F;}
		@Override public boolean addSlicerRecipe(ItemStack aInput, ItemStack aShape, ItemStack aOutput, long aDuration, long aEUt) {return F;}
		@Override public boolean addImplosionRecipe(ItemStack aInput1, long aInput2, ItemStack aOutput1, ItemStack aOutput2) {return F;}
		@Override public boolean addGrinderRecipe(ItemStack aInput1, ItemStack aInput2, ItemStack aOutput1, ItemStack aOutput2, ItemStack aOutput3, ItemStack aOutput4) {return F;}
		@Override public boolean addDistillationRecipe(ItemStack aInput1, long aInput2, ItemStack aOutput1, ItemStack aOutput2, ItemStack aOutput3, ItemStack aOutput4, long aDuration, long aEUt) {return F;}
		@Override public boolean addLatheRecipe(ItemStack aInput1, ItemStack aOutput1, ItemStack aOutput2, long aDuration, long aEUt) {return F;}
		@Override public boolean addCutterRecipe(ItemStack aInput, FluidStack aLubricant, ItemStack aOutput1, ItemStack aOutput2, long aDuration, long aEUt) {return F;}
		@Override public boolean addCutterRecipe(ItemStack aInput, ItemStack aOutput1, ItemStack aOutput2, long aDuration, long aEUt) {return F;}
		@Override public boolean addBoxingRecipe(ItemStack aContainedItem, ItemStack aEmptyBox, ItemStack aFullBox, long aDuration, long aEUt) {return F;}
		@Override public boolean addUnboxingRecipe(ItemStack aFullBox, ItemStack aContainedItem, ItemStack aEmptyBox, long aDuration, long aEUt) {return F;}
		@Override public boolean addVacuumFreezerRecipe(ItemStack aInput1, ItemStack aOutput1, long aDuration) {return F;}
		@Override public boolean addFuel(ItemStack aInput1, ItemStack aOutput1, long aEU, long aType) {return F;}
		@Override public boolean addAmplifier(ItemStack aAmplifierItem, long aDuration, long aAmplifierAmountOutputted) {return F;}
		@Override public boolean addBrewingRecipe(ItemStack aIngredient, Fluid aInput, Fluid aOutput, boolean aHidden) {return F;}
		@Override public boolean addFermentingRecipe(FluidStack aInput, FluidStack aOutput, long aDuration, boolean aHidden) {return F;}
		@Override public boolean addFluidHeaterRecipe(ItemStack aCircuit, FluidStack aInput, FluidStack aOutput, long aDuration, long aEUt) {return F;}
		@Override public boolean addDistilleryRecipe(ItemStack aCircuit, FluidStack aInput, FluidStack aOutput, long aDuration, long aEUt, boolean aHidden) {return F;}
		@Override public boolean addFluidSolidifierRecipe(ItemStack aMold, FluidStack aInput, ItemStack aOutput, long aDuration, long aEUt) {return F;}
		@Override public boolean addFluidSmelterRecipe(ItemStack aInput, ItemStack aRemains, FluidStack aOutput, long aChance, long aDuration, long aEUt) {return F;}
		@Override public boolean addFluidExtractionRecipe(ItemStack aInput, ItemStack aRemains, FluidStack aOutput, long aChance, long aDuration, long aEUt) {return F;}
		@Override public boolean addFluidCannerRecipe(ItemStack aInput, ItemStack aOutput, FluidStack aFluidInput, FluidStack aFluidOutput) {return F;}
		@Override public boolean addChemicalBathRecipe(ItemStack aInput, FluidStack aBathingFluid, ItemStack aOutput1, ItemStack aOutput2, ItemStack aOutput3, long[] aChances, long aDuration, long aEUt) {return F;}
		@Override public boolean addElectromagneticSeparatorRecipe(ItemStack aInput, ItemStack aOutput1, ItemStack aOutput2, ItemStack aOutput3, long[] aChances, long aDuration, long aEUt) {return F;}
		@Override public boolean addPrinterRecipe(ItemStack aInput, FluidStack aFluid, ItemStack aSpecialSlot, ItemStack aOutput, long aDuration, long aEUt) {return F;}
		@Override public boolean addAutoclaveRecipe(ItemStack aInput, FluidStack aFluid, ItemStack aOutput, long aChance, long aDuration, long aEUt) {return F;}
		@Override public boolean addMixerRecipe(ItemStack aInput1, ItemStack aInput2, ItemStack aInput3, ItemStack aInput4, FluidStack aFluidInput, FluidStack aFluidOutput, ItemStack aOutput, long aDuration, long aEUt) {return F;}
		@Override public boolean addLaserEngraverRecipe(ItemStack aItemToEngrave, ItemStack aLens, ItemStack aEngravedItem, long aDuration, long aEUt) {return F;}
		@Override public boolean addFormingPressRecipe(ItemStack aItemToImprint, ItemStack aForm, ItemStack aImprintedItem, long aDuration, long aEUt) {return F;}
		@Override public boolean addSifterRecipe(ItemStack aItemToSift, ItemStack[] aSiftedItems, long[] aChances, long aDuration, long aEUt) {return F;}
		@Override public boolean addArcFurnaceRecipe(ItemStack aInput, ItemStack[] aOutputs, long[] aChances, long aDuration, long aEUt) {return F;}
		@Override public boolean addPulveriserRecipe(ItemStack aInput, ItemStack[] aOutputs, long[] aChances, long aDuration, long aEUt) {return F;}
		@Override public boolean addShredderRecipe(ItemStack aInput, ItemStack[] aOutputs, long[] aChances, long aDuration, long aEUt) {return F;}
		@Override public boolean addCrusherRecipe(ItemStack aInput, ItemStack[] aOutputs, long[] aChances, long aDuration, long aEUt) {return F;}
		@Override public boolean addSharpeningRecipe(ItemStack aItemToSharpen, ItemStack aSharpenedItem, ItemStack aRemainingDust, long aDustChance, long aDuration, long aEUt) {return F;}
	}
}